'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var vue = require('vue');
require('../../../utils/index.js');
var type = require('./type.js');
require('../../../hooks/index.js');
var elementPlus = require('element-plus');
var useConfigInject = require('../../../hooks/useConfigInject.js');
var tools = require('../../../utils/tools.js');

var _sfc_main = vue.defineComponent({
  name: "BcSelect",
  emits: ["update:modelValue", "update:label", "fetch", "change"],
  props: type.selectProps,
  components: {
    ElSelect: elementPlus.ElSelect
  },
  setup(props, context) {
    const { arrayName, label: optionLabel, value: optionValue, response } = useConfigInject.useConfigInject("select", props);
    const optionsName = vue.computed(() => {
      var _a;
      return (_a = props.arrayName || arrayName.value) != null ? _a : "";
    });
    const responseWrap = vue.computed(() => {
      var _a, _b;
      return (_b = (_a = response.value) == null ? void 0 : _a.data) != null ? _b : "data";
    });
    const apiOptions = vue.ref([]);
    const selectOptions = vue.computed(() => {
      return [...props.options || apiOptions.value || []];
    });
    const needGroup = vue.computed(() => {
      if (!props.group) {
        return false;
      }
      return selectOptions.value.some((item) => item.children);
    });
    const displayText = vue.computed(() => {
      const value = Array.isArray(props.modelValue) ? props.modelValue : [props.modelValue];
      const res = [];
      value.forEach((item) => {
        let obj = {};
        if (props.modelValue instanceof Object) {
          obj = props.modelValue;
        } else {
          obj = selectOptions.value.find((each) => each[optionValue.value] === item) || {};
        }
        res.push(obj ? obj[optionLabel.value] : "");
      });
      return res.join(",");
    });
    const selectWidth = vue.computed(() => {
      if (!props.width) {
        return "";
      }
      if (typeof props.width === "string") {
        return props.width;
      } else {
        return props.width + "px";
      }
    });
    props.immediate && getList();
    props.defaultValue && context.emit("update:modelValue", props.defaultValue);
    function getList() {
      if (typeof props.api === "function") {
        props.api().then((data) => {
          if (data[responseWrap.value]) {
            apiOptions.value = data[responseWrap.value][optionsName.value] || data[responseWrap.value];
          }
          context.emit("fetch", apiOptions.value);
        });
      }
    }
    function hasValue(item) {
      const value = tools.getValue(item, optionLabel.value);
      if (value === "" || !!value) {
        return value;
      } else {
        return typeof item === "object" ? "" : item;
      }
    }
    function getObject(value) {
      if (typeof value === "object") {
        return value;
      }
      const res = selectOptions.value.find((item) => item[optionValue.value] === (value || props.modelValue));
      if (!res) {
        return {};
      }
      return res;
    }
    function getLabel(val) {
      const value = val || props.modelValue;
      if (Array.isArray(value)) {
        return value.reduce((res, curr) => {
          const result = selectOptions.value.find((item) => item[optionValue.value] === curr) || {};
          if (!result) {
            res.push("");
          }
          res.push(result[optionLabel.value]);
          return res;
        }, []);
      } else {
        const res = selectOptions.value.find((item) => item[optionValue.value] === value);
        if (!res) {
          return "";
        }
        return res[optionLabel.value];
      }
    }
    function getOptions() {
      return selectOptions.value;
    }
    function emitValue(val) {
      context.emit("update:modelValue", val);
      context.emit("change", val, getObject(val));
    }
    function emitLabel(val) {
      context.emit("update:label", getLabel(val));
    }
    context.expose({
      getOptions,
      getLabel
    });
    return {
      needGroup,
      displayText,
      selectOptions,
      selectWidth,
      optionValue,
      hasValue,
      getObject,
      getLabel,
      getOptions,
      emitLabel,
      emitValue
    };
  }
});

exports["default"] = _sfc_main;
//# sourceMappingURL=select.vue_vue_type_script_lang.js.map
